==> gtk-gnutella_0.96.3.orig.tar.gz: gtk-gnutella-0.96.3/src/core/oob_proxy.h <==
/*
 * $Id: oob_proxy.h 12147 2006-10-27 19:55:09Z cbiere $
 *
 * Copyright (c) 2004, Raphael Manfredi
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

/**
 * @ingroup core
 * @file
 *
 * Proxied Out-of-band queries.
 *
 * @author Raphael Manfredi
 * @date 2004
 */

#ifndef _core_oob_proxy_h_
#define _core_oob_proxy_h_

#include <glib.h>

/*
 * Public interface.
 */

struct gnutella_node;

void oob_proxy_init(void);
void oob_proxy_close(void);

void oob_proxy_create(struct gnutella_node *n);
gboolean oob_proxy_pending_results(
	struct gnutella_node *n, const gchar *muid,
	gint hits, gboolean udp_firewalled);
gboolean oob_proxy_got_results(struct gnutella_node *n, guint results);
const gchar *oob_proxy_muid_proxied(const gchar *muid);

#endif /* _core_oob_proxy_h_ */

/* vi: set ts=4: */

==> gtk-gnutella_0.96.4.orig.tar.gz: gtk-gnutella-0.96.4/src/core/oob_proxy.h <==
/*
 * $Id: oob_proxy.h 12824 2007-02-13 04:49:50Z cbiere $
 *
 * Copyright (c) 2004, Raphael Manfredi
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

/**
 * @ingroup core
 * @file
 *
 * Proxied Out-of-band queries.
 *
 * @author Raphael Manfredi
 * @date 2004
 */

#ifndef _core_oob_proxy_h_
#define _core_oob_proxy_h_

#include "common.h"

/*
 * Public interface.
 */

struct array;
struct gnutella_node;

void oob_proxy_init(void);
void oob_proxy_close(void);

void oob_proxy_create(struct gnutella_node *n);
gboolean oob_proxy_pending_results(
	struct gnutella_node *n, const gchar *muid,
	gint hits, gboolean udp_firewalled, const struct array *token);
gboolean oob_proxy_got_results(struct gnutella_node *n, guint results);
const gchar *oob_proxy_muid_proxied(const gchar *muid);

#endif /* _core_oob_proxy_h_ */

/* vi: set ts=4: */
